@@ -27,26 +27,52 @@ class explain():
         super(explain, self).__init__()
         self.param= None
 
+    # is classification function?
+
+    def is_classification_given_y_array(self, y_test):
+        is_classification = False
+        total = len(y_test)
+        total_unique = len(set(y_test))
+        if total < 30:
+            if total_unique < 10:
+                is_classification = True
+        else:
+            if total_unique < 20:
+                is_classification = True
+        return is_classification
+
 
     def ai(self,  df,  y, model, model_name="xgboost", mode=None):
         y_variable= "y_actual"
         y_variable_predict= "y_prediction"
 
 
+        # is classification?
+        is_classification= self.is_classification_given_y_array(y)
+
+        # If yes, then different shap functuions are required.
+        # get the shap value based on predcton and make a new dataframe.
+
+        # find predictions first as shap values need that.
+
+        prediction_col=[]
+
+        if model_name == "xgboost":
+            prediction_col = model.predict(xgboost.DMatrix(df))
+
+        elif model_name == "catboost":
+            prediction_col = model.predict(df.to_numpy())
+
+        else:
+            prediction_col = model.predict(df.to_numpy())
+
 
         #shap
         c = calculate_shap()
-        self.df_final = c.find(model, df, model_name=model_name)
+        self.df_final = c.find(model, df, prediction_col, is_classification, model_name=model_name)
 
         #prediction col
-        if model_name=="xgboost":
-            self.df_final[y_variable_predict] = model.predict(xgboost.DMatrix(df))
-
-        elif model_name=="catboost":
-            self.df_final[y_variable_predict] = model.predict(df.to_numpy())
-
-        else:
-            self.df_final[y_variable_predict] = model.predict(df.to_numpy())
+        self.df_final[y_variable_predict] = prediction_col
 
 
 
